SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

DROP SCHEMA IF EXISTS `uocintegra` ;
CREATE SCHEMA IF NOT EXISTS `uocintegra` DEFAULT CHARACTER SET utf8 ;
USE `uocintegra` ;

-- -----------------------------------------------------
-- Table `artefact`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `artefact` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `sec` INT(11) NOT NULL DEFAULT '0' ,
  `name` VARCHAR(20) NOT NULL ,
  `descShort` VARCHAR(50) NOT NULL ,
  `descript` MEDIUMTEXT NOT NULL ,
  `priory` VARCHAR(10) NOT NULL ,
  `fecini` DATE NOT NULL ,
  `fecfin` DATE NOT NULL ,
  `idState` INT(11) NOT NULL ,
  `effort` FLOAT NOT NULL ,
  `idUser` INT(11) NOT NULL ,
  `timestampA` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  `idUserA` INT(11) NOT NULL ,
  `idProject` INT(11) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1
COMMENT = 'Artefactos de un Projecto' ;


-- -----------------------------------------------------
-- Table `artefact_u`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `artefact_u` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `fecini` DATE NOT NULL  ,
  `fecfin` DATE NOT NULL  ,
  `iduserrol` INT(11) NOT NULL ,
  `idartefact` INT(11) NOT NULL ,
  `iduser` INT(11) NOT NULL ,
  `idrol` INT(11) NOT NULL ,
  `idproject` INT(11) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'Artefactos asignados en una fecha a un Usuario' ;


-- -----------------------------------------------------
-- Table `attachment`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `attachment` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `idartefact` INT(11) NOT NULL ,
  `sec_artefact` INT(11) NOT NULL DEFAULT '0' ,
  `descript` VARCHAR(50) NOT NULL ,
  `file_name_ext` VARCHAR(50) NOT NULL ,
  `file_name_int` VARCHAR(50) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'documentos adjuntados a un artefacto' ;


-- -----------------------------------------------------
-- Table `config`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `config` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(50) NOT NULL ,
  `value` VARCHAR(50) NOT NULL ,
  `type` VARCHAR(20) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 15
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'Parámetros de Configuración' ;


-- -----------------------------------------------------
-- Table `history`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `history` (
  `id` INT(11) NOT NULL ,
  `IdArtefact` INT(11) NOT NULL ,
  `secArtefact` INT(11) NOT NULL ,
  `name` VARCHAR(20) NOT NULL ,
  `descriptShort` VARCHAR(50) NOT NULL ,
  `descript` MEDIUMTEXT NOT NULL ,
  `priory` VARCHAR(10) NOT NULL ,
  `dateIni` DATE NOT NULL ,
  `dateFin` DATE NOT NULL ,
  `idStateAct` BIGINT(20) NOT NULL ,
  `effortAct` FLOAT NOT NULL ,
  `idUserAct` INT(11) NOT NULL ,
  `timestampA` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  `idUserA` INT(11) NOT NULL ,
  `idProject` INT(11) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'historia de un artefacto' ;


-- -----------------------------------------------------
-- Table `inform`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `inform` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(50) NOT NULL ,
  `descript` MEDIUMTEXT NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 4
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'Tipos de Informes' ;


-- -----------------------------------------------------
-- Table `project`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `project` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `prefix_code` VARCHAR(10) NOT NULL ,
  `name` VARCHAR(50) NOT NULL ,
  `descript` MEDIUMTEXT NOT NULL ,
  `fecopen` DATE NOT NULL ,
  `fecclose` DATE NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'Proyectos' ;


-- -----------------------------------------------------
-- Table `rol`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `rol` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `idproject` INT(11) NOT NULL ,
  `name` VARCHAR(50) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'Roles de un  Proyecto' ;


-- -----------------------------------------------------
-- Table `state`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `state` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `idproject` INT(11) NOT NULL ,
  `name` VARCHAR(50) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'Estados de un Projecto' ;


-- -----------------------------------------------------
-- Table `user`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `user` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `login` VARCHAR(20) NOT NULL ,
  `password` VARCHAR(20) NOT NULL ,
  `name` VARCHAR(60) NOT NULL ,
  `company` VARCHAR(50) NULL DEFAULT NULL ,
  `email` VARCHAR(50) NOT NULL ,
  `intentos` INT(11) NOT NULL DEFAULT '0' ,
  `locked` TINYINT(1) NOT NULL DEFAULT '1' ,
  `type` VARCHAR(20) NOT NULL ,
  `last_login` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'Usuarios Autorizados.' ;


-- -----------------------------------------------------
-- Table `user_rol`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `user_rol` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `iduser` INT(11) NOT NULL ,
  `idrol` INT(11) NOT NULL ,
  `idproject` INT(11) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'Roles de los Usuarios en un Proyecto' ;


-- -----------------------------------------------------
-- Table `workflow`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `workflow` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `idproject` INT(11) NOT NULL ,
  `idrol` INT(11) NOT NULL ,
  `idstate` INT(11) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1, 
COMMENT = 'Workflow de un Projecto' ;


-- -----------------------------------------------------
-- Table `workflow_state`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `workflow_state` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `idworkflow` INT(11) NOT NULL ,
  `idstate` INT(11) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 23
DEFAULT CHARACTER SET = latin1;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

-- -----------------------------------------------------
-- Data for table `user`
-- -----------------------------------------------------
START TRANSACTION;
USE `uocIntegra`;
INSERT INTO `user` (`id`,`login`,`password`,`name`,`company`,`email`,`intentos`,`locked`,`type`,`last_login`) VALUES (1,'admin','admin','admin','uoc','mpineda@uoc.edu',0,0,'Administrador','2011-12-03 18:09:00');
INSERT INTO `user` (`id`,`login`,`password`,`name`,`company`,`email`,`intentos`,`locked`,`type`,`last_login`) VALUES (2,'user1','user1','usuario 1','uoc','user1@uoc.edu',0,0,'Avanzado','2011-12-03 18:09:00');
INSERT INTO `user` (`id`,`login`,`password`,`name`,`company`,`email`,`intentos`,`locked`,`type`,`last_login`) VALUES (3,'user2','user2','usuario 2','uoc','user2@uoc.edu',0,0,'Normal','2011-12-03 18:09:00');
COMMIT;

-- -----------------------------------------------------
-- Data for table `config`
-- -----------------------------------------------------
START TRANSACTION;
USE `uocIntegra`;
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (1,'mail.server.host','smtp.gmail.com','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (2,'mail.server.port','465','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (3,'mail.server.tls.enable','true','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (4,'mail.server.username','username','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (5,'mail.server.password','password','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (6,'mail.server.from','Integra@gmail.com','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (7,'mail.subject.prefix','Administrador','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (8,'mail.server.auth.enable','true','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (9,'mail.smtp.socketFactory.port','465','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (10,'mail.smtp.socketFactory.class','javax.net.ssl.SSLSocketFactory','Email');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (11,'ftp.repository.directory','\attachment','Project');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (12,'login_attempts','3','User');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (13,'swing_artefact','3','User');
INSERT INTO `config` (`id`,`name`,`value`,`type`) VALUES (14,'swing_project','3','User');
COMMIT;

-- -----------------------------------------------------
-- Data for table `inform`
-- -----------------------------------------------------
START TRANSACTION;
USE `uocIntegra`;
INSERT INTO `inform` (`id`,`name`,`descript`) VALUES (1,'INFPROJ01','Informe Resumen Proyecto');
INSERT INTO `inform` (`id`,`name`,`descript`) VALUES (2,'INFPROJ02','Informe Completo Proyecto');
INSERT INTO `inform` (`id`,`name`,`descript`) VALUES (3,'INFPROJ03','Informe Evolución Proyecto');
COMMIT;
